Enum walletd::EthereumFormat
source · pub enum EthereumFormat {
Checksummed,
NonChecksummed,
}Expand description
EthereumFormat is an enum that represents the format of an Ethereum address (checksummed or non-checksummed)
Variants
Checksummed
Checksummed is the checksummed format of an Ethereum address where the case of each letter is mixed using the checksum algorithm
NonChecksummed
NonChecksummed is the non-checksummed format of an Ethereum address where the letters are all lowercase